==> sentry-10.0.1-py27-none-any.whl: sentry/static/sentry/app/views/eventsV2/eventInputName.tsx <==
import React from 'react';
import styled from 'react-emotion';
import {browserHistory} from 'react-router';

import {Client} from 'app/api';
import {t} from 'app/locale';
import overflowEllipsis from 'app/styles/overflowEllipsis';
import {Organization, SavedQuery} from 'app/types';
import withApi from 'app/utils/withApi';

import {addErrorMessage} from 'app/actionCreators/indicator';

import InlineInput from 'app/components/inputInline';
import {handleUpdateQueryName} from './savedQuery/utils';

import EventView from './eventView';

type Props = {
  api: Client;
  organization: Organization;
  eventView: EventView;
  savedQuery: SavedQuery | undefined;
};

const NAME_DEFAULT = t('Untitled query');

/**
 * Allows user to edit the name of the query. Upon blurring from it, it will
 * save the name change immediately (but not changes in the query)
 */
class EventInputName extends React.Component<Props> {
  private refInput = React.createRef<InlineInput>();

  onBlur = (event: React.ChangeEvent<HTMLInputElement>) => {
    const {api, organization, savedQuery, eventView} = this.props;
    const nextQueryName = (event.target.value || '').trim();

    // Do not update automatically if
    // 1) New name is empty
    // 2) It is a new query
    // 3) The new name is same as the old name
    if (!nextQueryName) {
      addErrorMessage(t('Please set a name for this query'));

      // Help our users re-focus so they cannot run away from this problem
      if (this.refInput.current) {
        this.refInput.current.focus();
      }

      return;
    }

    if (!savedQuery || savedQuery.name === nextQueryName) {
      return;
    }

    // This ensures that we are updating SavedQuery.name only.
    // Changes on QueryBuilder table will not be saved.
    const nextEventView = EventView.fromSavedQuery({
      ...savedQuery,
      name: nextQueryName,
    });

    handleUpdateQueryName(api, organization, nextEventView).then(
      (_updatedQuery: SavedQuery) => {
        // The current eventview may have changes that are not explicitly saved.
        // So, we just preserve them and change its name
        const renamedEventView = eventView.clone();
        renamedEventView.name = nextQueryName;

        browserHistory.push({
          pathname: location.pathname,
          query: renamedEventView.generateQueryStringObject(),
        });
      }
    );
  };

  render() {
    const {eventView} = this.props;

    return (
      <StyledListHeader>
        <InlineInput
          ref={this.refInput}
          name="discover2-query-name"
          disabled={!eventView.id}
          value={eventView.name || NAME_DEFAULT}
          onBlur={this.onBlur}
        />
      </StyledListHeader>
    );
  }
}

const StyledListHeader = styled('div')`
  font-size: ${p => p.theme.headerFontSize};
  color: ${p => p.theme.gray4};
  grid-column: 1/2;
  align-self: center;
  ${overflowEllipsis};
`;

export default withApi(EventInputName);

==> sentry-20.6.0-py27-none-any.whl: sentry/static/sentry/app/views/eventsV2/eventInputName.tsx <==
import React from 'react';
import styled from '@emotion/styled';
import {browserHistory} from 'react-router';

import {Client} from 'app/api';
import {t} from 'app/locale';
import overflowEllipsis from 'app/styles/overflowEllipsis';
import {Organization, SavedQuery} from 'app/types';
import withApi from 'app/utils/withApi';
import {addErrorMessage} from 'app/actionCreators/indicator';
import InlineInput from 'app/components/inputInline';
import EventView from 'app/utils/discover/eventView';

import {handleUpdateQueryName} from './savedQuery/utils';

type Props = {
  api: Client;
  organization: Organization;
  eventView: EventView;
  savedQuery: SavedQuery | undefined;
};

const NAME_DEFAULT = t('Untitled query');

/**
 * Allows user to edit the name of the query. Upon blurring from it, it will
 * save the name change immediately (but not changes in the query)
 */
class EventInputName extends React.Component<Props> {
  private refInput = React.createRef<InlineInput>();

  onBlur = (event: React.ChangeEvent<HTMLInputElement>) => {
    const {api, organization, savedQuery, eventView} = this.props;
    const nextQueryName = (event.target.value || '').trim();

    // Do not update automatically if
    // 1) New name is empty
    // 2) It is a new query
    // 3) The new name is same as the old name
    if (!nextQueryName) {
      addErrorMessage(t('Please set a name for this query'));

      // Help our users re-focus so they cannot run away from this problem
      if (this.refInput.current) {
        this.refInput.current.focus();
      }

      return;
    }

    if (!savedQuery || savedQuery.name === nextQueryName) {
      return;
    }

    // This ensures that we are updating SavedQuery.name only.
    // Changes on QueryBuilder table will not be saved.
    const nextEventView = EventView.fromSavedQuery({
      ...savedQuery,
      name: nextQueryName,
    });

    handleUpdateQueryName(api, organization, nextEventView).then(
      (_updatedQuery: SavedQuery) => {
        // The current eventview may have changes that are not explicitly saved.
        // So, we just preserve them and change its name
        const renamedEventView = eventView.clone();
        renamedEventView.name = nextQueryName;

        browserHistory.push(renamedEventView.getResultsViewUrlTarget(organization.slug));
      }
    );
  };

  render() {
    const {eventView} = this.props;

    return (
      <StyledListHeader>
        <InlineInput
          ref={this.refInput}
          name="discover2-query-name"
          disabled={!eventView.id}
          value={eventView.name || NAME_DEFAULT}
          onBlur={this.onBlur}
        />
      </StyledListHeader>
    );
  }
}

const StyledListHeader = styled('div')`
  font-size: ${p => p.theme.headerFontSize};
  color: ${p => p.theme.gray700};
  grid-column: 1/2;
  min-height: 30px;
  ${overflowEllipsis};
`;

export default withApi(EventInputName);
